from django_typer.management import TyperCommand
import json
import sys


class Command(TyperCommand):
    requires_system_checks = []
    requires_migrations_checks = False

    def handle(self, test_arg: int, test_option: bool = False):
        return json.dumps(
            {
                "typer": test_arg,
                "test_option": test_option,
                "modules": list(sys.modules.keys()),
            }
        )



from django.core.management.base import BaseCommand, CommandParser
import sys
import json


class Command(BaseCommand):
    requires_system_checks = []
    requires_migrations_checks = False

    def add_arguments(self, parser: CommandParser) -> None:
        parser.add_argument("test_arg", type=int)
        parser.add_argument("--test-option", action="store_true")
        return super().add_arguments(parser)

    def handle(self, test_arg, test_option, **_):
        return json.dumps(
            {
                "no_typer": test_arg,
                "test_option": test_option,
                "modules": list(sys.modules.keys()),
            }
        )



import os
import sys
import django


def test():
    # verify that the environment is set up correctly - this is used in CI to make
    # sure we're testing against the dependencies we think we are

    expected_python = os.environ["TEST_PYTHON_VERSION"]
    expected_django = os.environ["TEST_DJANGO_VERSION"]

    expected_python = tuple(int(v) for v in expected_python.split(".") if v)
    assert sys.version_info[: len(expected_python)] == expected_python, (
        f"Python Version Mismatch: {sys.version_info[: len(expected_python)]} != "
        f"{expected_python}"
    )

    try:
        expected_django = tuple(int(v) for v in expected_django.split(".") if v)
        assert django.VERSION[: len(expected_django)] == expected_django, (
            f"Django Version Mismatch: {django.VERSION[: len(expected_django)]} != "
            f"{expected_django}"
        )
    except ValueError:
        assert expected_django == django.__version__
